@@ -18,7 +18,7 @@
  */
 package org.apache.brooklyn.util.core.task;
 
-import java.util.List;
+import java.util.Collection;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.Callable;
@@ -32,12 +32,14 @@ import org.apache.brooklyn.api.mgmt.TaskAdaptable;
 import org.apache.brooklyn.api.mgmt.TaskFactory;
 import org.apache.brooklyn.core.entity.EntityInternal;
 import org.apache.brooklyn.core.mgmt.BrooklynTaskTags;
+import org.apache.brooklyn.util.collections.MutableSet;
 import org.apache.brooklyn.util.core.flags.TypeCoercions;
 import org.apache.brooklyn.util.core.task.ImmediateSupplier.ImmediateUnsupportedException;
 import org.apache.brooklyn.util.core.task.ImmediateSupplier.ImmediateValueNotAvailableException;
 import org.apache.brooklyn.util.exceptions.Exceptions;
 import org.apache.brooklyn.util.guava.Maybe;
 import org.apache.brooklyn.util.javalang.JavaClassNames;
+import org.apache.brooklyn.util.javalang.Reflections;
 import org.apache.brooklyn.util.repeat.Repeater;
 import org.apache.brooklyn.util.time.CountdownTimer;
 import org.apache.brooklyn.util.time.Duration;
@@ -48,13 +50,12 @@ import org.slf4j.LoggerFactory;
 import com.google.common.annotations.Beta;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
-import com.google.common.collect.Sets;
 import com.google.common.reflect.TypeToken;
 
 /** 
  * Resolves a given object, as follows:
  * <li> If it is a {@link Tasks} or a {@link DeferredSupplier} then get its contents
- * <li> If it's a map and {@link #deep(boolean)} is requested, it applies resolution to contents
+ * <li> If it's a map/iterable and {@link #deep(boolean, Boolean)} is requested, it applies resolution to contents
  * <li> It applies coercion
  * <p>
  * Fluent-style API exposes a number of other options.
@@ -104,10 +105,11 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
     private static final Logger log = LoggerFactory.getLogger(ValueResolver.class);
     
     final Object value;
-    final Class<T> type;
+    final TypeToken<T> typeT;
     ExecutionContext exec;
     String description;
     boolean forceDeep;
+    Boolean deepTraversalUsesRootType;
     /** null means do it if you can; true means always, false means never */
     Boolean embedResolutionInTask;
     /** timeout on execution, if possible, or if embedResolutionInTask is true */
@@ -126,17 +128,17 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
     AtomicBoolean started = new AtomicBoolean(false);
     boolean expired;
     
-    ValueResolver(Object v, Class<T> type) {
+    ValueResolver(Object v, TypeToken<T> type) {
         this.value = v;
-        this.type = type;
+        this.typeT = type;
         checkTypeNotNull();
         parentOriginalValue = null;
         parentTimer = null;
     }
     
-    ValueResolver(Object v, Class<T> type, ValueResolver<?> parent) {
+    ValueResolver(Object v, TypeToken<T> type, ValueResolver<?> parent) {
         this.value = v;
-        this.type = type;
+        this.typeT = type;
         checkTypeNotNull();
         
         exec = parent.exec;
@@ -162,6 +164,9 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
             this.v = v;
         }
         public <T> ValueResolver<T> as(Class<T> type) {
+            return as(TypeToken.of(type));
+        }
+        public <T> ValueResolver<T> as(TypeToken<T> type) {
             return new ValueResolver<T>(v, type);
         }
     }
@@ -169,23 +174,23 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
     /** returns a copy of this resolver which can be queried, even if the original (single-use instance) has already been copied */
     @Override
     public ValueResolver<T> clone() {
-        return cloneReplacingValueAndType(value, type);
+        return cloneReplacingValueAndType(value, typeT);
     }
     
-    <S> ValueResolver<S> cloneReplacingValueAndType(Object newValue, Class<S> superType) {
+    <S> ValueResolver<S> cloneReplacingValueAndType(Object newValue, TypeToken<S> superType) {
         // superType expected to be either type or Object.class
-        if (!superType.isAssignableFrom(type)) {
-            throw new IllegalStateException("superType must be assignable from " + type);
+        if (!superType.isAssignableFrom(typeT)) {
+            throw new IllegalStateException("superType must be assignable from " + typeT);
         }
         ValueResolver<S> result = new ValueResolver<S>(newValue, superType)
             .context(exec).description(description)
             .embedResolutionInTask(embedResolutionInTask)
-            .deep(forceDeep)
+            .deep(forceDeep, deepTraversalUsesRootType)
             .timeout(timeout)
             .immediately(immediately)
             .recursive(recursive);
         if (returnDefaultOnGet) {
-            if (!superType.isInstance(defaultValue)) {
+            if (!superType.getRawType().isInstance(defaultValue)) {
                 throw new IllegalStateException("Existing default value " + defaultValue + " not compatible with new type " + superType);
             }
             @SuppressWarnings("unchecked")
@@ -250,9 +255,23 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
         else return Maybe.absent("No default value set");
     }
     
-    /** causes nested structures (maps, lists) to be descended and nested unresolved values resolved */
+    /** causes nested structures (maps, lists) to be descended and nested unresolved values resolved.
+     * for legacy reasons this sets deepTraversalUsesRootType.
+     * @deprecated use {@link #deep(boolean, boolean)} */
     public ValueResolver<T> deep(boolean forceDeep) {
+        return deep(true, true);
+    }
+    /** causes nested structures (maps, lists) to be descended and nested unresolved values resolved.
+     * if the second argument is true, the type specified here is used against non-map/iterable items
+     * inside maps and iterables encountered. if false, any generic signature on the supplied type
+     * is traversed to match contained items. if null (default), it is inferred from the type,
+     * those with generics imply false, and those without imply true. 
+     * 
+     * see {@link Tasks#resolveDeepValue(Object, Class, ExecutionContext, String)} and 
+     * {@link Tasks#resolveDeepValueExactly(Object, TypeToken, ExecutionContext, String)}. */
+    public ValueResolver<T> deep(boolean forceDeep, Boolean deepTraversalUsesRootType) {
         this.forceDeep = forceDeep;
+        this.deepTraversalUsesRootType = deepTraversalUsesRootType;
         return this;
     }
 
@@ -302,7 +321,7 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
     }
 
     protected void checkTypeNotNull() {
-        if (type==null) 
+        if (typeT==null) 
             throw new NullPointerException("type must be set to resolve, for '"+value+"'"+(description!=null ? ", "+description : ""));
     }
 
@@ -344,7 +363,7 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
             exec = BasicExecutionContext.getCurrentExecutionContext();
         }
         
-        if (!recursive && type != Object.class) {
+        if (!recursive && typeT.getRawType() != Object.class) {
             throw new IllegalStateException("When non-recursive resolver requested the return type must be Object " +
                     "as the immediately resolved value could be a number of (deferred) types.");
         }
@@ -359,9 +378,10 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
         checkTypeNotNull();
         Object v = this.value;
         
-        //if the expected type is a closure or map and that's what we have, we're done (or if it's null);
-        //but not allowed to return a future or DeferredSupplier as the resolved value
-        if (v==null || (!forceDeep && type.isInstance(v) && !Future.class.isInstance(v) && !DeferredSupplier.class.isInstance(v) && !TaskFactory.class.isInstance(v)))
+        //if the expected type is what we have, we're done (or if it's null);
+        //but not allowed to return a future or DeferredSupplier as the resolved value,
+        //and not if generics signatures might be different
+        if (v==null || (!forceDeep && TypeToken.of(typeT.getRawType()).equals(typeT) && typeT.getRawType().isInstance(v) && !Future.class.isInstance(v) && !DeferredSupplier.class.isInstance(v) && !TaskFactory.class.isInstance(v)))
             return Maybe.of((T) v);
         
         try {
@@ -405,7 +425,7 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
                     
                     return (result.isPresent())
                         ? recursive
-                            ? new ValueResolver<T>(result.get(), type, this).getMaybe()
+                            ? new ValueResolver<T>(result.get(), typeT, this).getMaybe()
                                 : result
                                 : result;
                 } catch (ImmediateSupplier.ImmediateUnsupportedException e) {
@@ -434,7 +454,13 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
                         // (should discourage this in favour of task factories which can be transiently interrupted?)
                         BrooklynTaskTags.addTagDynamically(task, BrooklynTaskTags.NON_TRANSIENT_TASK_TAG);
                     }
-                    exec.submit(task);
+                    if (timer==null && !Thread.currentThread().isInterrupted() && !isEvaluatingImmediately()) {
+                        // if all conditions above:  no timeout, not immediate, and not interrupted,
+                        // then we can run in this thread
+                        exec.get(task);
+                    } else {
+                        exec.submit(task);
+                    }
                 }
             }
 
@@ -483,7 +509,7 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
                     String description = getDescription();
                     TaskBuilder<Object> tb = Tasks.<Object>builder()
                             .body(callable)
-                            .displayName("Resolving dependent value")
+                            .displayName("Resolving dependent value of deferred supplier")
                             .description(description);
                     if (isTransientTask) tb.tag(BrooklynTaskTags.TRANSIENT_TASK_TAG);
                     
@@ -503,50 +529,89 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
                     }
                 }
 
-            } else if (v instanceof Map) {
-                //and if a map or list we look inside
-                Map result = Maps.newLinkedHashMap();
-                for (Map.Entry<?,?> entry : ((Map<?,?>)v).entrySet()) {
-                    Maybe<?> kk = new ValueResolver(entry.getKey(), type, this)
-                        .description( (description!=null ? description+", " : "") + "map key "+entry.getKey() )
-                        .getMaybe();
-                    if (kk.isAbsent()) return (Maybe<T>)kk;
-                    Maybe<?> vv = new ValueResolver(entry.getValue(), type, this)
-                        .description( (description!=null ? description+", " : "") + "map value for key "+kk.get() )
-                        .getMaybe();
-                    if (vv.isAbsent()) return (Maybe<T>)vv;
-                    result.put(kk.get(), vv.get());
-                }
-                return Maybe.of((T) result);
-
-            } else if (v instanceof Set) {
-                Set result = Sets.newLinkedHashSet();
-                int count = 0;
-                for (Object it : (Set)v) {
-                    Maybe<?> vv = new ValueResolver(it, type, this)
-                        .description( (description!=null ? description+", " : "") + "entry "+count )
-                        .getMaybe();
-                    if (vv.isAbsent()) return (Maybe<T>)vv;
-                    result.add(vv.get());
-                    count++;
-                }
-                return Maybe.of((T) result);
-
-            } else if (v instanceof Iterable) {
-                List result = Lists.newArrayList();
-                int count = 0;
-                for (Object it : (Iterable)v) {
-                    Maybe<?> vv = new ValueResolver(it, type, this)
-                        .description( (description!=null ? description+", " : "") + "entry "+count )
-                        .getMaybe();
-                    if (vv.isAbsent()) return (Maybe<T>)vv;
-                    result.add(vv.get());
-                    count++;
-                }
-                return Maybe.of((T) result);
-
             } else {
-                return TypeCoercions.tryCoerce(v, TypeToken.of(type));
+                if (supportsDeepResolution(v)) {
+
+                    // allows user to resolveValue(map, String) with the effect
+                    // that things _in_ the collection would be resolved as string.
+                    // alternatively use generics.
+                    boolean useRootObect = typeT.getRawType()==Object.class || Boolean.TRUE.equals(deepTraversalUsesRootType);
+                    
+                    TypeToken<?>[] innerTypes = new TypeToken<?>[0];
+                    if (!useRootObect) {
+                        if (!TypeToken.of(typeT.getRawType()).equals(typeT)) {
+                            innerTypes = Reflections.getGenericParameterTypeTokens(typeT);
+                        } else {
+                            if (deepTraversalUsesRootType==null) {
+                                // for null, autodetect
+                                useRootObect = true;
+                            } else {
+                                // we will warn and fall back to autodetect for legacy reasons
+                                // (same if the number of inner types above is wrong)
+                            }
+                        }
+                    }
+                        
+                    // restrict deep resolution to the same set of types as calling code;
+                    // in particular need to avoid for "interesting iterables" such as PortRange
+                    
+                    if (v instanceof Map) {
+                        TypeToken<?> keyT = typeT;
+                        TypeToken<?> valT = typeT;
+                        if (!useRootObect) {
+                            if (innerTypes.length==2) {
+                                keyT = innerTypes[0];
+                                valT = innerTypes[1];
+                            } else {
+                                // deprecated in 1.0.0
+                                log.warn("Coercing deep into map "+v+" when expected to coerce to incompatible "+typeT+"; "
+                                    + "will attempt conversion of keys and values, but this behaviour is deprecated. "
+                                    + "Should correctly request conversion to generic TypeToken<Map<...>>.");
+                            }
+                        }
+                        //and if a map or list we look inside
+                        Map result = Maps.newLinkedHashMap();
+                        for (Map.Entry<?,?> entry : ((Map<?,?>)v).entrySet()) {
+                            Maybe<?> kk = new ValueResolver(entry.getKey(), keyT, this)
+                                .description( (description!=null ? description+", " : "") + "map key "+entry.getKey() )
+                                .getMaybe();
+                            if (kk.isAbsent()) return (Maybe<T>)kk;
+                            Maybe<?> vv = new ValueResolver(entry.getValue(), valT, this)
+                                .description( (description!=null ? description+", " : "") + "map value for key "+kk.get() )
+                                .getMaybe();
+                            if (vv.isAbsent()) return (Maybe<T>)vv;
+                            result.put(kk.get(), vv.get());
+                        }
+                        return Maybe.of((T) result);
+        
+                    } else if (v instanceof Iterable) {
+                        TypeToken<?> entryT = typeT;
+                        if (!useRootObect) {
+                            if (innerTypes.length==1) {
+                                entryT = innerTypes[0];
+                            } else {
+                                // deprecated in 1.0.0
+                                log.warn("Coercing deep into iterable "+v+" when expected to coerce to incompatible "+typeT+"; "
+                                    + "will attempt conversion of keys and values, but this behaviour is deprecated. "
+                                    + "Should correctly request conversion to generic TypeToken<Map<...>>.");
+                            }
+                        }
+                        
+                        Collection<Object> result = v instanceof Set ? MutableSet.of() : Lists.newArrayList();
+                        int count = 0;
+                        for (Object it : (Iterable)v) {
+                            Maybe<?> vv = new ValueResolver(it, entryT, this)
+                                .description( (description!=null ? description+", " : "") + "entry "+count )
+                                .getMaybe();
+                            if (vv.isAbsent()) return (Maybe<T>)vv;
+                            result.add(vv.get());
+                            count++;
+                        }
+                        return Maybe.of((T) result);
+                    }
+                }
+                
+                return TypeCoercions.tryCoerce(v, typeT);
             }
 
         } catch (Exception e) {
@@ -566,13 +631,18 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
         }
         
         if (recursive) {
-            return new ValueResolver(v, type, this).getMaybe();
+            return new ValueResolver(v, typeT, this).getMaybe();
         } else {
-            // T expected to be Object.class
             return (Maybe<T>) Maybe.of(v);
         }
     }
 
+    // whether value resolution supports deep resolution
+    @Beta
+    public static boolean supportsDeepResolution(Object v) {
+        return (v instanceof Map || v instanceof Collection);
+    }
+    
     protected String getDescription() {
         return description!=null ? description : ""+value;
     }
@@ -580,12 +650,12 @@ public class ValueResolver<T> implements DeferredSupplier<T>, Iterable<Maybe<Obj
         if (parentOriginalValue!=null) return parentOriginalValue;
         return value;
     }
-    protected Class<T> getType() {
-        return type;
+    protected TypeToken<T> getTypeToken() {
+        return typeT;
     }
 
     @Override
     public String toString() {
-        return JavaClassNames.cleanSimpleClassName(this)+"["+JavaClassNames.cleanSimpleClassName(type)+" "+value+"]";
+        return JavaClassNames.cleanSimpleClassName(this)+"["+typeT+" "+value+"]";
     }
 }
