@@ -81,7 +81,8 @@ import groovy.lang.Closure;
 @SuppressWarnings({"rawtypes", "unchecked"})
 @Catalog(name="Auto-scaler", description="Policy that is attached to a Resizable entity and dynamically "
         + "adjusts its size in response to either keep a metric within a given range, or in response to "
-        + "POOL_COLD and POOL_HOT events")
+        + "POOL_COLD and POOL_HOT events",
+        iconUrl="classpath://org/apache/brooklyn/policy/autoscaler.png")
 public class AutoScalerPolicy extends AbstractPolicy {
     
     private static final Logger LOG = LoggerFactory.getLogger(AutoScalerPolicy.class);
@@ -768,8 +769,8 @@ public class AutoScalerPolicy extends AbstractPolicy {
                         int desiredSize = Math.min(max, Math.max(min, currentSize));
 
                         if (currentSize != desiredSize) {
-                            if (LOG.isInfoEnabled()) LOG.info("{} resizing pool {} immediateley from {} to {} (due to new pool size limits)", new Object[] {this, poolEntity, currentSize, desiredSize});
-                            getResizeOperator().resize(poolEntity, desiredSize);
+                            if (LOG.isInfoEnabled()) LOG.info("{} resizing pool {} triggering resize computation due to new pool size limits, current {} exceeds bound of {}", new Object[] {this, poolEntity, currentSize, desiredSize});
+                            resizeNow("Size "+currentSize+" not in new bounds");
                         }
                         
                     } catch (Exception e) {
